@@ -1,5 +1,5 @@
 #
-# $Id: Log.pm,v a5b24eee501b 2016/01/02 17:04:51 gomor $
+# $Id: Log.pm 360 2014-11-25 06:50:22Z gomor $
 #
 # core::log Brik
 #
@@ -7,14 +7,14 @@ package Metabrik::Core::Log;
 use strict;
 use warnings;
 
-our $VERSION = '1.20.0';
+our $VERSION = '1.02';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: a5b24eee501b $',
-      tags => [ qw(main core) ],
+      revision => '$Revision: 360 $',
+      tags => [ qw(core main log) ],
       attributes => {
          color => [ qw(0|1) ],
          level => [ qw(0|1|2|3) ],
@@ -24,12 +24,12 @@ sub brik_properties {
          level => 1,
       },
       commands => {
-         info => [ qw(string caller|OPTIONAL) ],
-         verbose => [ qw(string caller|OPTIONAL) ],
-         warning => [ qw(string caller|OPTIONAL) ],
-         error => [ qw(string caller|OPTIONAL) ],
-         fatal => [ qw(string caller|OPTIONAL) ],
-         debug => [ qw(string caller|OPTIONAL) ],
+         info => [ qw(string) ],
+         verbose => [ qw(string) ],
+         warning => [ qw(string) ],
+         error => [ qw(string) ],
+         fatal => [ qw(string) ],
+         debug => [ qw(string) ],
       },
       require_modules => {
          'Term::ANSIColor' => [ ],
@@ -77,9 +77,7 @@ sub error {
 
    print $self->_msg(($caller) ||= caller(), $msg);
 
-   # Returning undef is my official way of stating an error occured:
-   # Number 0 is for stating a false condition occured, not not error.
-   return;
+   return 0;
 }
 
 sub fatal {
@@ -175,55 +173,9 @@ __END__
 
 Metabrik::Core::Log - core::log Brik
 
-=head1 SYNOPSIS
-
-   use Metabrik::Core::Log;
-
-   my $LOG = Metabrik::Core::Log->new;
-
-=head1 DESCRIPTION
-
-This Brik is the default logging mechanism: output on console. You could write a different logging Brik as long as it respects the API as described in the B<METHODS> paragraph below. You don't need to use this Brik directly. It is auto-loaded by B<core::context> Brik and is stored in its B<log> Attribute.
-
-=head1 ATTRIBUTES
-
-At B<The Metabrik Shell>, just type:
-
-L<get core::log>
-
-=head1 COMMANDS
-
-At B<The Metabrik Shell>, just type:
-
-L<help core::log>
-
-=head1 METHODS
-
-=over 4
-
-=item B<brik_properties>
-
-=item B<debug>
-
-=item B<error>
-
-=item B<fatal>
-
-=item B<info>
-
-=item B<verbose>
-
-=item B<warning>
-
-=back
-
-=head1 SEE ALSO
-
-L<Metabrik>
-
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
